summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
diff options
context:
space:
mode:
Diffstat (limited to 'win/CS/HandBrakeWPF/Properties/Resources.Designer.cs')
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.Designer.cs20
1 files changed, 10 insertions, 10 deletions
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
index 353beb922..f0aba3163 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
+++ b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
@@ -4246,6 +4246,15 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
+ /// Looks up a localized string similar to Reset.
+ /// </summary>
+ public static string QueueView_Reset {
+ get {
+ return ResourceManager.GetString("QueueView_Reset", resourceCulture);
+ }
+ }
+
+ /// <summary>
/// Looks up a localized string similar to Retry All Jobs.
/// </summary>
public static string QueueView_ResetAllJobs {
@@ -4264,7 +4273,7 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
/// Looks up a localized string similar to Retry Selected Jobs.
/// </summary>
public static string QueueView_ResetSelectedJobs {
get {
@@ -4273,15 +4282,6 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Retry.
- /// </summary>
- public static string QueueView_Retry {
- get {
- return ResourceManager.GetString("QueueView_Retry", resourceCulture);
- }
- }
-
- /// <summary>
/// Looks up a localized string similar to Shutdown.
/// </summary>
public static string QueueView_Shutdown {
@@ -4264,7 +4273,7 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Retry Selected Jobs.
+ /// Looks up a localized string similar to Reset Selected Jobs.
/// </summary>
public static string QueueView_ResetSelectedJobs {